@@ -1,7 +1,8 @@
 /* R-stop -- implement some functions for keeping track of how many SEXPs 
  * 	are PROTECTed, and UNPROTECTing them in the case of a fortran stop.
  * Also, implement Rstop, which calls error, as a replacement
- * for fortran STOP (call Rstop(message) */
+ * for fortran STOP (call Rstop(message)
+ * and rwarn to send an R warning() (added by Jim Lindsay)*/
 #include <R.h>
 #include <Rdefines.h>
 
@@ -22,3 +23,5 @@ void my_unprotect(int n)
 }
 
 void F77_SUB(rstop)(char *message) { error(message); }
+
+void F77_SUB(rwarn)(char *message) { warning(message); }
